#ifndef H_CDW_GROWISOFS_OPTIONS
#define H_CDW_GROWISOFS_OPTIONS

#include "main.h"
#include "cdw_form.h"
#include "cdw_task.h"

#define CDW_GROWISOFS_OPTIONS_N_FIELDS 2


cdw_rv_t cdw_growisofs_options_form(cdw_form_t *cdw_form, void *task, int first_col, int second_col, int width_wide, int width_narrow);
cdw_rv_t cdw_growisofs_options_validate(cdw_task_t *task, int *fi);
cdw_rv_t cdw_growisofs_options_save(cdw_form_t *cdw_form, cdw_task_t *task);



#endif /* H_CDW_GROWISOFS_OPTIONS */
